@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
-require "rspec/stubbed_env/version"
-
 # This Gem
-require "rspec/stubbed_env/test_helpers"
+require "rspec/stubbed_env/version"
+require "rspec/stubbed_env/hide_helpers"
+require "rspec/stubbed_env/stub_helpers"
 require "rspec/stubbed_env/config"
 
 #
@@ -19,6 +19,15 @@ require "rspec/stubbed_env/config"
 #   end
 # end
 #
+# describe 'my hidden test' do
+#   include_context 'with hidden env'
+#   before do
+#     hide_env('FOO')
+#   end
+#   it 'does a thing' do
+#     expect(ENV['FOO']).to be_nil
+#   end
+# end
 module RSpec
   # Gem Namespace
   module StubbedEnv
